@@ -1,27 +1,24 @@
-/* vim: set sw=2 ts=2 sts=2 et: */
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
- * ephy-download.h
- * This file is part of Epiphany
+ *  Copyright © 2011 Igalia S.L.
  *
- * Copyright © 2011 - Igalia S.L.
+ *  This file is part of Epiphany.
  *
- * Epiphany is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * Epiphany is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  Epiphany is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
+ *  You should have received a copy of the GNU General Public License
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _EPHY_DOWNLOAD_H
-#define _EPHY_DOWNLOAD_H
+#pragma once
 
 #include <glib-object.h>
 #include <webkit2/webkit2.h>
@@ -61,10 +58,7 @@ guint32       ephy_download_get_start_time        (EphyDownload *download);
 EphyDownloadActionType ephy_download_get_action   (EphyDownload *download);
 void          ephy_download_set_action            (EphyDownload *download,
                                                    EphyDownloadActionType action);
-gboolean      ephy_download_do_download_action    (EphyDownload          *download,
-                                                   EphyDownloadActionType action,
-                                                   guint32                user_time);
+gboolean      ephy_download_do_download_action    (EphyDownload *download,
+                                                   EphyDownloadActionType action);
 
 G_END_DECLS
-
-#endif /* _EPHY_DOWNLOAD_H */
