@@ -26,7 +26,6 @@
 #include "ephy-dbus-util.h"
 #include "ephy-debug.h"
 #include "ephy-embed-prefs.h"
-#include "ephy-embed-private.h"
 #include "ephy-embed-type-builtins.h"
 #include "ephy-embed-utils.h"
 #include "ephy-encodings.h"
@@ -608,10 +607,12 @@ new_connection_cb (GDBusServer     *server,
                    EphyEmbedShell  *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-  EphyWebExtensionProxy *extension = ephy_web_extension_proxy_new (connection);
+  EphyWebExtensionProxy *extension;
+
+  extension = ephy_web_extension_proxy_new (connection);
   ephy_embed_shell_watch_web_extension (shell, extension);
 
-  ephy_uri_tester_register_dbus_object (priv->uri_tester, connection);
+  ephy_uri_tester_handle_new_dbus_connection (priv->uri_tester, connection);
 
   g_signal_connect_object (extension, "page-created",
                            G_CALLBACK (web_extension_page_created), shell, 0);
@@ -737,10 +738,9 @@ ephy_embed_shell_startup (GApplication *application)
 
   G_APPLICATION_CLASS (ephy_embed_shell_parent_class)->startup (application);
 
-  /* We're not remoting, setup the Web Context if we are not running in a test.
-     Tests already do this after construction. */
-  if (priv->mode != EPHY_EMBED_SHELL_MODE_TEST)
-    ephy_embed_shell_create_web_context (embed_shell);
+  ephy_embed_shell_create_web_context (embed_shell);
+
+  priv->uri_tester = ephy_uri_tester_new ();
 
   ephy_embed_shell_setup_web_extensions_server (shell);
 
@@ -904,9 +904,6 @@ ephy_embed_shell_constructed (GObject *object)
     priv->user_content = webkit_user_content_manager_new ();
   }
 
-  if (mode != EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER)
-    priv->uri_tester = ephy_uri_tester_new ();
-
   g_signal_connect_object (ephy_snapshot_service_get_default (),
                            "snapshot-saved", G_CALLBACK (snapshot_saved_cb),
                            shell, 0);
