@@ -3,22 +3,23 @@
  *  Copyright © 2000-2003 Marco Pesenti Gritti
  *  Copyright © 2011 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EPHY_EMBED_SHELL_H
-#define EPHY_EMBED_SHELL_H
+#pragma once
 
 #include <webkit2/webkit2.h>
 #include "ephy-downloads-manager.h"
@@ -77,5 +78,3 @@ EphyDownloadsManager     *ephy_embed_shell_get_downloads_manager    (EphyEmbedSh
 EphyHostsManager         *ephy_embed_shell_get_hosts_manager        (EphyEmbedShell *shell);
 
 G_END_DECLS
-
-#endif /* !EPHY_EMBED_SHELL_H */
