@@ -1,5 +1,4 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2; -*- */
-/* vim: set sw=2 ts=2 sts=2 et: */
 /*
  *  Copyright © 2007 Xan Lopez
  *  Copyright © 2008 Jan Alonzo
@@ -7,18 +6,20 @@
  *  Copyright © 2009 Igalia S.L.
  *  Copyright © 2009 Collabora Ltd.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -29,6 +30,7 @@
 #include "ephy-embed-shell.h"
 #include "ephy-embed-utils.h"
 #include "ephy-find-toolbar.h"
+#include "ephy-notification-container.h"
 #include "ephy-prefs.h"
 #include "ephy-settings.h"
 #include "ephy-string.h"
@@ -60,6 +62,7 @@ struct _EphyEmbed {
   GtkPaned *paned;
   WebKitWebView *web_view;
   GSList *destroy_on_transition_list;
+  GtkWidget *overlay;
   GtkWidget *floating_bar;
   GtkWidget *progress;
   GtkWidget *fullscreen_message_label;
@@ -508,19 +511,9 @@ static gboolean
 ephy_embed_attach_inspector_cb (WebKitWebInspector *inspector,
                                 EphyEmbed          *embed)
 {
-  GtkWidget *inspector_view = GTK_WIDGET (webkit_web_inspector_get_web_view (inspector));
-  int inspected_view_height;
-  guint attached_height;
-
-  inspected_view_height = gtk_widget_get_allocated_height (GTK_WIDGET (embed->web_view));
-  attached_height = webkit_web_inspector_get_attached_height (inspector);
-  gtk_paned_set_position (embed->paned, inspected_view_height - attached_height);
-
-  gtk_paned_add2 (embed->paned, inspector_view);
-  gtk_widget_show (inspector_view);
   embed->inspector_loaded = TRUE;
 
-  return TRUE;
+  return FALSE;
 }
 
 static gboolean
@@ -708,7 +701,6 @@ ephy_embed_constructed (GObject *object)
   EphyEmbedShell *shell = ephy_embed_shell_get_default ();
   GtkWidget *paned;
   WebKitWebInspector *inspector;
-  GtkWidget *overlay;
 
   g_signal_connect (shell, "window-restored",
                     G_CALLBACK (ephy_embed_restored_window_cb), embed);
@@ -717,12 +709,12 @@ ephy_embed_constructed (GObject *object)
                     G_CALLBACK (ephy_embed_mapped_cb), NULL);
 
   /* Skeleton */
-  overlay = gtk_overlay_new ();
+  embed->overlay = gtk_overlay_new ();
 
-  gtk_widget_add_events (overlay,
+  gtk_widget_add_events (embed->overlay,
                          GDK_ENTER_NOTIFY_MASK |
                          GDK_LEAVE_NOTIFY_MASK);
-  gtk_container_add (GTK_CONTAINER (overlay), GTK_WIDGET (embed->web_view));
+  gtk_container_add (GTK_CONTAINER (embed->overlay), GTK_WIDGET (embed->web_view));
 
   /* Floating message popup for fullscreen mode. */
   embed->fullscreen_message_label = gtk_label_new (NULL);
@@ -730,7 +722,7 @@ ephy_embed_constructed (GObject *object)
   gtk_widget_set_halign (embed->fullscreen_message_label, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (embed->fullscreen_message_label, GTK_ALIGN_CENTER);
   gtk_widget_set_no_show_all (embed->fullscreen_message_label, TRUE);
-  gtk_overlay_add_overlay (GTK_OVERLAY (overlay), embed->fullscreen_message_label);
+  gtk_overlay_add_overlay (GTK_OVERLAY (embed->overlay), embed->fullscreen_message_label);
   ephy_embed_set_fullscreen_message (embed, FALSE);
 
   /* statusbar is hidden by default */
@@ -739,14 +731,14 @@ ephy_embed_constructed (GObject *object)
   gtk_widget_set_valign (embed->floating_bar, GTK_ALIGN_END);
   gtk_widget_set_no_show_all (embed->floating_bar, TRUE);
 
-  gtk_overlay_add_overlay (GTK_OVERLAY (overlay), embed->floating_bar);
+  gtk_overlay_add_overlay (GTK_OVERLAY (embed->overlay), embed->floating_bar);
 
   embed->progress = gtk_progress_bar_new ();
   gtk_style_context_add_class (gtk_widget_get_style_context (embed->progress),
                                GTK_STYLE_CLASS_OSD);
   gtk_widget_set_halign (embed->progress, GTK_ALIGN_FILL);
   gtk_widget_set_valign (embed->progress, GTK_ALIGN_START);
-  gtk_overlay_add_overlay (GTK_OVERLAY (overlay), embed->progress);
+  gtk_overlay_add_overlay (GTK_OVERLAY (embed->overlay), embed->progress);
 
   embed->find_toolbar = ephy_find_toolbar_new (embed->web_view);
   g_signal_connect (embed->find_toolbar, "close",
@@ -761,7 +753,7 @@ ephy_embed_constructed (GObject *object)
 
   embed->progress_update_handler_id = g_signal_connect (embed->web_view, "notify::estimated-load-progress",
                                                         G_CALLBACK (progress_update), object);
-  gtk_paned_pack1 (GTK_PANED (paned), GTK_WIDGET (overlay),
+  gtk_paned_pack1 (GTK_PANED (paned), GTK_WIDGET (embed->overlay),
                    TRUE, FALSE);
 
   gtk_box_pack_start (GTK_BOX (embed),
@@ -957,3 +949,32 @@ ephy_embed_inspector_is_loaded (EphyEmbed *embed)
 
   return embed->inspector_loaded;
 }
+
+void
+ephy_embed_attach_notification_container (EphyEmbed *embed)
+{
+  EphyNotificationContainer *container;
+
+  g_return_if_fail (EPHY_IS_EMBED (embed));
+
+  container = ephy_notification_container_get_default ();
+  if (gtk_widget_get_parent (GTK_WIDGET (container)) == NULL)
+    gtk_overlay_add_overlay (GTK_OVERLAY (embed->overlay), GTK_WIDGET (container));
+}
+
+void
+ephy_embed_detach_notification_container (EphyEmbed *embed)
+{
+  EphyNotificationContainer *container;
+
+  g_return_if_fail (EPHY_IS_EMBED (embed));
+
+  container = ephy_notification_container_get_default ();
+  if (gtk_widget_get_parent (GTK_WIDGET (container)) == embed->overlay) {
+    /* Since the overlay container will own the one and only reference to the
+     * notification widget, removing it from the container will destroy the
+     * singleton. To prevent this, add a reference to it before removing it
+     * from the container. */
+    gtk_container_remove (GTK_CONTAINER (embed->overlay), g_object_ref (container));
+  }
+}
