@@ -851,7 +851,7 @@ ephy_uri_tester_rewrite_uri (EphyUriTester *tester,
                              const char    *request_uri,
                              const char    *page_uri)
 {
-  char *modified_uri;
+  char *modified_uri = NULL;
   char *result;
 
   /* Should we block the URL outright? */
@@ -870,9 +870,13 @@ ephy_uri_tester_rewrite_uri (EphyUriTester *tester,
   if (!modified_uri)
     modified_uri = g_strdup (request_uri);
 
-  result = https_everywhere_context_rewrite (tester->https_everywhere_context,
-                                             modified_uri);
-  g_free (modified_uri);
+  if (g_str_has_prefix (request_uri, SOUP_URI_SCHEME_HTTP)) {
+    result = https_everywhere_context_rewrite (tester->https_everywhere_context,
+                                               modified_uri);
+    g_free (modified_uri);
+  } else {
+    result = modified_uri;
+  }
 
   return result;
 }
@@ -1078,13 +1082,12 @@ https_everywhere_context_init_cb (HTTPSEverywhereContext *context,
   if (error) {
     if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
       g_error ("Failed to initialize HTTPS Everywhere context: %s", error->message);
+  } else {
+    g_list_foreach (tester->deferred_requests, (GFunc)handle_deferred_request, tester);
+    ephy_uri_tester_update_https_everywhere_rulesets (tester);
   }
 
-  g_list_foreach (tester->deferred_requests, (GFunc)handle_deferred_request, tester);
   g_list_free_full (tester->deferred_requests, (GDestroyNotify)deferred_request_free);
-
-  ephy_uri_tester_update_https_everywhere_rulesets (tester);
-
   g_object_unref (tester);
 }
 
