@@ -23,6 +23,8 @@
 
 #include <webkit2/webkit2.h>
 
+#include "ephy-embed-shell.h"
+#include "ephy-history-types.h"
 #include "ephy-security-levels.h"
 
 G_BEGIN_DECLS
@@ -31,6 +33,19 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (EphyWebView, ephy_web_view, EPHY, WEB_VIEW, WebKitWebView)
 
+#define EPHY_WEB_VIEW_NON_SEARCH_REGEX  "(" \
+                                        "^[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9](:[0-9]+)?.*$|" \
+                                        "^::[0-9a-f:]*$|" \
+                                        "^[0-9a-f:]+:[0-9a-f:]*$|" \
+                                        "^https?://[^/\\.[:space:]]+.*$|" \
+                                        "^about:.*$|" \
+                                        "^data:.*$|" \
+                                        "^file:.*$" \
+                                        ")"
+
+#define EPHY_WEB_VIEW_DOMAIN_REGEX "^localhost(\\.[^[:space:]]+)?(:\\d+)?(:[0-9]+)?(/.*)?$|" \
+                                   "^[^\\.[:space:]]+\\.[^\\.[:space:]]+.*$|"
+
 typedef enum
 {
   EPHY_WEB_VIEW_NAV_BACK    = 1 << 0,
@@ -116,4 +131,16 @@ char                      *ephy_web_view_get_web_app_title_finish (EphyWebView
                                                                    GAsyncResult              *result,
                                                                    GError                   **error);
 
+void                       ephy_web_view_set_visit_type           (EphyWebView *view, 
+                                                                   EphyHistoryPageVisitType visit_type);
+EphyHistoryPageVisitType   ephy_web_view_get_visit_type           (EphyWebView *view);
+void                       ephy_web_view_popups_manager_reset     (EphyWebView               *view);
+void                       ephy_web_view_save                     (EphyWebView               *view,
+                                                                   const char                *uri);
+void                       ephy_web_view_load_homepage            (EphyWebView               *view);
+
+char *                     ephy_web_view_create_web_application   (EphyWebView               *view,
+                                                                   const char                *title,
+                                                                   GdkPixbuf                 *icon);
+
 G_END_DECLS
