@@ -50,7 +50,6 @@ struct _EphyWebExtension {
   gboolean initialized;
 
   GDBusConnection *dbus_connection;
-  GCancellable *cancellable;
 
   EphyFormAuthDataCache *form_auth_data_cache;
   GHashTable *form_auth_data_save_requests;
@@ -278,8 +277,9 @@ should_store_cb (const char *username,
     return;
 
   web_extension = ephy_web_extension_get ();
-  permission = ephy_hosts_manager_get_save_password_permission_for_address (web_extension->hosts_manager,
-                                                                            uri_string);
+  permission = ephy_hosts_manager_get_permission_for_address (web_extension->hosts_manager,
+                                                              EPHY_HOST_PERMISSION_TYPE_SAVE_PASSWORD,
+                                                              uri_string);
 
   if (permission == EPHY_HOST_PERMISSION_DENY) {
     LOG ("User/password storage permission previously denied. Not asking about storing.");
@@ -392,8 +392,10 @@ fill_form_cb (const char *username,
 
   LOG ("Found: user %s pass (hidden)", username_node ? username : "(none)");
   if (username_node) {
+    g_object_set_data (G_OBJECT (username_node), "ephy-is-auto-filling", GINT_TO_POINTER (TRUE));
     webkit_dom_html_input_element_set_auto_filled (username_node, TRUE);
     webkit_dom_html_input_element_set_editing_value (username_node, username);
+    g_object_set_data (G_OBJECT (username_node), "ephy-is-auto-filling", GINT_TO_POINTER (FALSE));
   }
   webkit_dom_html_input_element_set_auto_filled (password_node, TRUE);
   webkit_dom_html_input_element_set_editing_value (password_node, password);
@@ -404,15 +406,17 @@ ephy_form_auth_data_compare (EphyFormAuthData  *form_data,
                              EphyEmbedFormAuth *form_auth)
 {
   WebKitDOMNode *username_node;
+  WebKitDOMNode *password_node;
   char *username_field_name = NULL;
-  char *password_field_name;
+  char *password_field_name = NULL;
   gboolean retval;
 
   username_node = ephy_embed_form_auth_get_username_node (form_auth);
   if (username_node)
     g_object_get (username_node, "name", &username_field_name, NULL);
-  g_object_get (ephy_embed_form_auth_get_password_node (form_auth),
-                "name", &password_field_name, NULL);
+  password_node = ephy_embed_form_auth_get_password_node (form_auth);
+  if (password_node)
+    g_object_get (password_node, "name", &password_field_name, NULL);
 
   retval = g_strcmp0 (username_field_name, form_data->form_username) == 0 &&
            g_strcmp0 (password_field_name, form_data->form_password) == 0;
@@ -909,6 +913,9 @@ username_node_input_cb (WebKitDOMNode  *username_node,
   WebKitDOMDocument *document;
   WebKitDOMElement *main_div;
 
+  if (g_object_get_data (G_OBJECT (username_node), "ephy-is-auto-filling"))
+    return TRUE;
+
   g_object_set_data (G_OBJECT (username_node), "ephy-user-ever-edited", GINT_TO_POINTER (TRUE));
   document = webkit_web_page_get_dom_document (web_page);
   remove_user_choices (document);
@@ -1291,9 +1298,7 @@ ephy_web_extension_dispose (GObject *object)
     extension->form_auth_data_save_requests = NULL;
   }
 
-  g_clear_object (&extension->cancellable);
   g_clear_object (&extension->dbus_connection);
-
   g_clear_object (&extension->extension);
 
   G_OBJECT_CLASS (ephy_web_extension_parent_class)->dispose (object);
@@ -1363,8 +1368,6 @@ ephy_web_extension_initialize (EphyWebExtension   *extension,
                             G_CALLBACK (ephy_web_extension_page_created_cb),
                             extension);
 
-  extension->cancellable = g_cancellable_new ();
-
   observer = g_dbus_auth_observer_new ();
   g_signal_connect (observer, "authorize-authenticated-peer",
                     G_CALLBACK (authorize_authenticated_peer_cb), extension);
