@@ -249,7 +249,7 @@ ephy_remove_tracking_from_uri (const char *uri_string)
   return ret;
 }
 
-static char *
+char *
 ephy_uri_decode (const char *uri_string)
 {
   char *decoded_uri;
@@ -263,41 +263,6 @@ ephy_uri_decode (const char *uri_string)
   return decoded_uri ? decoded_uri : g_strdup (uri_string);
 }
 
-char *
-ephy_uri_sanitize (const char *uri_string)
-{
-  SoupURI *uri;
-  char *sanitized_uri;
-
-  /* Trick: the parameter does not actually have to be a URI. We allow calling
-   * this function with any address, like about:blank. Just return in that case.
-   */
-  uri = soup_uri_new (uri_string);
-  if (!uri)
-    return g_strdup (uri_string);
-
-  /* Use soup_uri_to_string to remove the password component of the URI. */
-  sanitized_uri = soup_uri_to_string (uri, FALSE);
-  soup_uri_free (uri);
-
-  return sanitized_uri;
-}
-
-char *
-ephy_uri_decode_and_sanitize (const char *uri_string)
-{
-
-  char *sanitized_uri;
-  char *result;
-
-  sanitized_uri = ephy_uri_sanitize (uri_string);
-  result = ephy_uri_decode (sanitized_uri);
-
-  g_free (sanitized_uri);
-
-  return result;
-}
-
 char *
 ephy_uri_normalize (const char *uri_string)
 {
