@@ -89,10 +89,10 @@ ephy_bookmark_set_property (GObject      *object,
       ephy_bookmark_set_time_added (self, g_value_get_int64 (value));
       break;
     case PROP_TITLE:
-      self->title = g_value_dup_string (value);
+      ephy_bookmark_set_title (self, g_value_get_string (value));
       break;
     case PROP_URL:
-      self->url = g_value_dup_string (value);
+      ephy_bookmark_set_url (self, g_value_get_string (value));
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -130,8 +130,9 @@ ephy_bookmark_finalize (GObject *object)
 {
   EphyBookmark *self = EPHY_BOOKMARK (object);
 
-  g_clear_pointer (&self->url, g_free);
-  g_clear_pointer (&self->title, g_free);
+  g_free (self->url);
+  g_free (self->title);
+  g_free (self->id);
 
   g_sequence_free (self->tags);
 
@@ -281,8 +282,8 @@ EphyBookmark *
 ephy_bookmark_new (const char *url, const char *title, GSequence *tags)
 {
   return g_object_new (EPHY_TYPE_BOOKMARK,
-                       "url", g_strdup (url),
-                       "title", g_strdup (title),
+                       "url", url,
+                       "title", title,
                        "tags", tags,
                        "time-added", g_get_real_time (),
                        NULL);
