@@ -133,8 +133,10 @@ ephy_bookmarks_manager_finalize (GObject *object)
 {
   EphyBookmarksManager *self = EPHY_BOOKMARKS_MANAGER (object);
 
-  g_clear_pointer (&self->bookmarks, g_sequence_free);
-  g_clear_pointer (&self->tags, g_sequence_free);
+  g_sequence_free (self->bookmarks);
+  g_sequence_free (self->tags);
+
+  g_free (self->gvdb_filename);
 
   G_OBJECT_CLASS (ephy_bookmarks_manager_parent_class)->finalize (object);
 }
@@ -239,6 +241,12 @@ bookmark_url_changed_cb (EphyBookmark         *bookmark,
   g_signal_emit (self, signals[BOOKMARK_URL_CHANGED], 0, bookmark);
 }
 
+EphyBookmarksManager *
+ephy_bookmarks_manager_new (void)
+{
+  return EPHY_BOOKMARKS_MANAGER (g_object_new (EPHY_TYPE_BOOKMARKS_MANAGER, NULL));
+}
+
 void
 ephy_bookmarks_manager_add_bookmark (EphyBookmarksManager *self,
                                      EphyBookmark         *bookmark)
@@ -571,7 +579,7 @@ ephy_bookmarks_manager_load_from_file (EphyBookmarksManager *self)
   list = gvdb_table_get_names (table, &length);
   for (i = 0; i < length; i++)
     ephy_bookmarks_manager_create_tag (self, list[i]);
-
+  g_strfreev (list);
   gvdb_table_free (table);
 
   /* Get bookmarks table */
@@ -615,9 +623,12 @@ ephy_bookmarks_manager_load_from_file (EphyBookmarksManager *self)
     ephy_bookmark_set_modification_time (bookmark, modified);
     ephy_bookmark_set_is_uploaded (bookmark, uploaded);
     g_sequence_prepend (bookmarks, bookmark);
+
+    g_variant_unref (value);
   }
   ephy_bookmarks_manager_add_bookmarks (self, bookmarks);
 
+  g_strfreev (list);
   gvdb_table_free (table);
   g_sequence_free (bookmarks);
   gvdb_table_free (root_table);
