@@ -69,6 +69,7 @@ struct _PrefsDialog {
   GtkWidget *restore_session_checkbutton;
   GtkWidget *popups_allow_checkbutton;
   GtkWidget *adblock_allow_checkbutton;
+  GtkWidget *enable_plugins_checkbutton;
 
   /* fonts */
   GtkWidget *use_gnome_fonts_checkbutton;
@@ -372,7 +373,7 @@ server_message_received_cb (WebKitUserContentManager *manager,
       FxACallbackData *cb_data;
 
       text = g_strdup_printf ("<span fgcolor='#e6780b'>%s</span>",
-                              _("Please don't leave this page until you have completed the verification."));
+                              _("Please don’t leave this page until you have completed the verification."));
       gtk_label_set_markup (GTK_LABEL (dialog->sync_sign_in_details), text);
       gtk_widget_set_visible (dialog->sync_sign_in_details, TRUE);
 
@@ -521,6 +522,7 @@ prefs_dialog_class_init (PrefsDialogClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, restore_session_checkbutton);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, popups_allow_checkbutton);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, adblock_allow_checkbutton);
+  gtk_widget_class_bind_template_child (widget_class, PrefsDialog, enable_plugins_checkbutton);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, download_button_hbox);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, download_button_label);
 
@@ -1421,6 +1423,11 @@ setup_general_page (PrefsDialog *dialog)
                    dialog->adblock_allow_checkbutton,
                    "active",
                    G_SETTINGS_BIND_INVERT_BOOLEAN);
+  g_settings_bind (web_settings,
+                   EPHY_PREFS_WEB_ENABLE_PLUGINS,
+                   dialog->enable_plugins_checkbutton,
+                   "active",
+                   G_SETTINGS_BIND_DEFAULT);
 
   create_download_path_button (dialog);
   create_search_engine_combo (GTK_COMBO_BOX (dialog->search_engine_combo));
