@@ -44,7 +44,6 @@
 #include "ephy-location-entry.h"
 #include "ephy-notebook.h"
 #include "ephy-prefs.h"
-#include "ephy-private.h"
 #include "ephy-session.h"
 #include "ephy-settings.h"
 #include "ephy-shell.h"
@@ -70,11 +69,17 @@ window_cmd_new_window (GSimpleAction *action,
                        GVariant      *parameter,
                        gpointer       user_data)
 {
+  EphyWindow *new_window;
   EphyEmbed *embed;
-  EphyWindow *new_window = ephy_window_new ();
+  EphyShell *shell = ephy_shell_get_default ();
 
-  embed = ephy_shell_new_tab (ephy_shell_get_default (),
-                              new_window, NULL, 0);
+  if (ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (shell)) == EPHY_EMBED_SHELL_MODE_INCOGNITO) {
+    ephy_open_default_instance_window ();
+    return;
+  }
+
+  new_window = ephy_window_new ();
+  embed = ephy_shell_new_tab (shell, new_window, NULL, 0);
   ephy_web_view_load_homepage (ephy_embed_get_web_view (embed));
   ephy_window_activate_location (new_window);
 }
@@ -277,8 +282,7 @@ window_cmd_quit (GSimpleAction *action,
                  GVariant      *parameter,
                  gpointer       user_data)
 {
-  if (ephy_shell_close_all_windows (ephy_shell_get_default ()))
-    g_application_quit (g_application_get_default ());
+  ephy_shell_try_quit (ephy_shell_get_default ());
 }
 
 void
@@ -455,11 +459,17 @@ window_cmd_new_tab (GSimpleAction *action,
                     gpointer       user_data)
 {
   EphyWindow *window = user_data;
+  EphyLinkFlags flags = EPHY_LINK_NEW_TAB | EPHY_LINK_JUMP_TO;
+  gboolean load_homepage;
+
+  load_homepage = g_settings_get_boolean (EPHY_SETTINGS_MAIN,
+                                          EPHY_PREFS_HOMEPAGE_LOADS_IN_NEW_TABS);
+  if (load_homepage)
+    flags |= EPHY_LINK_HOME_PAGE;
 
   ephy_link_open (EPHY_LINK (window),
-                  "about:overview",
-                  NULL,
-                  EPHY_LINK_HOME_PAGE | EPHY_LINK_NEW_TAB | EPHY_LINK_JUMP_TO);
+                  "about:overview", /* Ignored when EPHY_LINK_HOME_PAGE is passed */
+                  NULL, flags);
 }
 
 static void
@@ -855,7 +865,7 @@ confirm_web_application_overwrite (GtkWindow *parent, const char *title)
                                    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                    GTK_MESSAGE_QUESTION,
                                    GTK_BUTTONS_NONE,
-                                   _("A web application named '%s' already exists. Do you want to replace it?"),
+                                   _("A web application named “%s” already exists. Do you want to replace it?"),
                                    title);
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
                           _("Cancel"),
@@ -899,10 +909,10 @@ dialog_save_as_application_response_cb (GtkDialog                 *dialog,
                                                 app_name,
                                                 gtk_image_get_pixbuf (GTK_IMAGE (data->image)));
     if (desktop_file)
-      message = g_strdup_printf (_("The application '%s' is ready to be used"),
+      message = g_strdup_printf (_("The application “%s” is ready to be used"),
                                  app_name);
     else
-      message = g_strdup_printf (_("The application '%s' could not be created"),
+      message = g_strdup_printf (_("The application “%s” could not be created"),
                                  app_name);
 
     notification = notify_notification_new (message,
